@@ -28,11 +28,12 @@ Arabic_LO_main
    <fa>Arabic Language Meta-Package for LibreOffice</fa>
    <fil_PH>Arabic Language Meta-Package for LibreOffice</fil_PH>
    <fi>Arabiankielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet de langue arabe pour LibreOffice</fr_BE>
+   <fr_BE>Arabic Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet de langue arabe pour LibreOffice</fr>
    <gl_ES>Árabe mta-paquete de idioma para LibreOffice</gl_ES>
+   <gu>Arabic Language Meta-Package for LibreOffice</gu>
    <he_IL>חבילת על לערבית עבור LibreOffice</he_IL>
-   <hi>Arabic Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु अरबी भाषा मेटा-पैकेज</hi>
    <hr>Arabic Language Meta-Package for LibreOffice</hr>
    <hu>Arabic Language Meta-Package for LibreOffice</hu>
    <id>Arabic Language Meta-Package for LibreOffice</id>
