@@ -28,9 +28,10 @@ Basque_LO_full
    <fa>Basque Language Meta-Package for LibreOffice</fa>
    <fil_PH>Basque Language Meta-Package for LibreOffice</fil_PH>
    <fi>Baskilainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet de langue Basque pour LibreOffice</fr_BE>
+   <fr_BE>Basque Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue Basque pour LibreOffice</fr>
    <gl_ES>Basco Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Basque Language Meta-Package for LibreOffice</gu>
    <he_IL>Basque Language Meta-Package for LibreOffice</he_IL>
    <hi>Basque Language Meta-Package for LibreOffice</hi>
    <hr>Basque Language Meta-Package for LibreOffice</hr>
