@@ -21,23 +21,24 @@ Chinese_CN_Default_Firefox_esr
    <de>Chinesische Lokalisation (vereinfachte reformierte Standardschriftzeichen) von “Firefox ESR”</de>
    <el>Απλοποιημένα Κινέζικα για Firefox ESR</el>
    <en>Chinese_simplified localisation of Firefox ESR</en>
-   <es_ES>Chinese_simplified localisation of Firefox ESR</es_ES>
+   <es_ES>Localización en Chino_simplificado de Firefox ESR</es_ES>
    <es>Localización Chino simplificado de Firefox ESR</es>
    <et>Chinese_simplified localisation of Firefox ESR</et>
    <eu>Chinese_simplified localisation of Firefox ESR</eu>
    <fa>Chinese_simplified localisation of Firefox ESR</fa>
    <fil_PH>Chinese_simplified localisation of Firefox ESR</fil_PH>
    <fi>Chinese_simplified localisation of Firefox ESR</fi>
-   <fr_BE>Localisation en chinois simplifié de Firefox ESR</fr_BE>
+   <fr_BE>Chinese_simplified localisation of Firefox ESR</fr_BE>
    <fr>Localisation en chinois simplifié de Firefox ESR</fr>
    <gl_ES>Chinese_simplified localisation of Firefox ESR</gl_ES>
+   <gu>Chinese_simplified localisation of Firefox ESR</gu>
    <he_IL>Chinese_simplified localisation of Firefox ESR</he_IL>
    <hi>Chinese_simplified localisation of Firefox ESR</hi>
    <hr>Chinese_simplified localisation of Firefox ESR</hr>
    <hu>Chinese_simplified localisation of Firefox ESR</hu>
    <id>Chinese_simplified localisation of Firefox ESR</id>
    <is>Chinese_simplified localisation of Firefox ESR</is>
-   <it>Chinese_simplified localisation of Firefox ESR</it>
+   <it>Localizzazione in cinese_semplificato di Firefox ESR</it>
    <ja>簡体中国語版 Firefox ESR</ja>
    <kk>Chinese_simplified localisation of Firefox ESR</kk>
    <ko>Chinese_simplified localisation of Firefox ESR</ko>
@@ -54,12 +55,12 @@ Chinese_CN_Default_Firefox_esr
    <ro>Chinese_simplified localisation of Firefox ESR</ro>
    <ru>Chinese_simplified localisation of Firefox ESR</ru>
    <sk>Chinese_simplified localisation of Firefox ESR</sk>
-   <sl>Chinese_simplified localisation of Firefox ESR</sl>
+   <sl>Kitajske (poenostavljeno) krajevne nastavitve za Firefox ESR</sl>
    <sq>Chinese_simplified localisation of Firefox ESR</sq>
    <sr>Chinese_simplified localisation of Firefox ESR</sr>
    <sv>Kinesisk_förenklad lokalisering av Firefox ESR</sv>
    <th>Chinese_simplified localisation of Firefox ESR</th>
-   <tr>Chinese_simplified localisation of Firefox ESR</tr>
+   <tr>Firefox ESR Basitleştirilmiş_Çince yerelleştirmesi</tr>
    <uk>Chinese_simplified localisation of Firefox ESR</uk>
    <vi>Chinese_simplified localisation of Firefox ESR</vi>
    <zh_CN>Chinese_simplified localisation of Firefox ESR</zh_CN>
