@@ -28,16 +28,17 @@ Chinese_CN_LO_Latest_full
    <fa>Chinese_simplified localisation of LibreOffice</fa>
    <fil_PH>Chinese_simplified localisation of LibreOffice</fil_PH>
    <fi>Yksinkertaistetun kiinankielen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Localisation en chinois-simplifié pour LibreOffice</fr_BE>
+   <fr_BE>Chinese_simplified localisation of LibreOffice</fr_BE>
    <fr>Localisation en chinois-simplifié pour LibreOffice</fr>
    <gl_ES>Localización de LibreOffice en chinés simplificado</gl_ES>
+   <gu>Chinese_simplified localisation of LibreOffice</gu>
    <he_IL>Chinese_simplified localisation of LibreOffice</he_IL>
-   <hi>Chinese_simplified localisation of LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस का सरल चीनी संस्करण</hi>
    <hr>Chinese_simplified localisation of LibreOffice</hr>
    <hu>Chinese_simplified localisation of LibreOffice</hu>
    <id>Chinese_simplified localisation of LibreOffice</id>
    <is>Chinese_simplified localisation of LibreOffice</is>
-   <it>Localizzazione in Cinese_semplificato di LibreOffice</it>
+   <it>Localizzazione in cinese_semplificato di LibreOffice</it>
    <ja>LibreOffice の簡体中国語版</ja>
    <kk>Chinese_simplified localisation of LibreOffice</kk>
    <ko>Chinese_simplified localisation of LibreOffice</ko>
