@@ -31,13 +31,14 @@ Chinese_CN_Thunderbird
    <fr_BE>Chinese_simplified localisation of Thunderbird</fr_BE>
    <fr>Localisation en chinois-simplifié pour Thunderbird</fr>
    <gl_ES>Localización do Thunderbird en chinés simplicado</gl_ES>
+   <gu>Chinese_simplified localisation of Thunderbird</gu>
    <he_IL>Chinese_simplified localisation of Thunderbird</he_IL>
-   <hi>Chinese_simplified localisation of Thunderbird</hi>
+   <hi>थंडरबर्ड का सरल चीनी संस्करण</hi>
    <hr>Chinese_simplified localisation of Thunderbird</hr>
    <hu>Chinese_simplified localisation of Thunderbird</hu>
    <id>Chinese_simplified localisation of Thunderbird</id>
    <is>Chinese_simplified localisation of Thunderbird</is>
-   <it>Localizzazione in Cinese_semplificato di Thunderbird</it>
+   <it>Localizzazione in cinese_semplificato di Thunderbird</it>
    <ja>Thunderbird の簡体中国語版</ja>
    <kk>Chinese_simplified localisation of Thunderbird</kk>
    <ko>Chinese_simplified localisation of Thunderbird</ko>
