@@ -28,16 +28,17 @@ Chinese_Font
    <fa>Chinese fonts packages</fa>
    <fil_PH>Chinese fonts packages</fil_PH>
    <fi>Kiinalaiset kirjasinpaketit</fi>
-   <fr_BE>Paquets pour polices chinoises</fr_BE>
+   <fr_BE>Chinese fonts packages</fr_BE>
    <fr>Paquets pour polices chinoises</fr>
    <gl_ES>Paquetes de fontes do chinés</gl_ES>
+   <gu>Chinese fonts packages</gu>
    <he_IL>חבילות גופנים סיניים</he_IL>
-   <hi>Chinese fonts packages</hi>
+   <hi>चीनी मुद्रलिपि पैकेज</hi>
    <hr>Chinese fonts packages</hr>
    <hu>Chinese fonts packages</hu>
    <id>Chinese fonts packages</id>
    <is>Chinese fonts packages</is>
-   <it>Pacchetti di fonts per il Cinese</it>
+   <it>Pacchetti di fonts per il cinese</it>
    <ja>中国語用のフォントパッケージ</ja>
    <kk>Chinese fonts packages</kk>
    <ko>Chinese fonts packages</ko>
