@@ -28,9 +28,10 @@ Croatian_LO_main
    <fa>Croatian LibreOffice Language Meta-Package</fa>
    <fil_PH>Croatian LibreOffice Language Meta-Package</fil_PH>
    <fi>Kroatiankielinen metatieto-paketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet langue croate pour LibreOffice</fr_BE>
+   <fr_BE>Croatian LibreOffice Language Meta-Package</fr_BE>
    <fr>Méta-Paquet langue croate pour LibreOffice</fr>
    <gl_ES>Croata Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Croatian LibreOffice Language Meta-Package</gu>
    <he_IL>Croatian LibreOffice Language Meta-Package</he_IL>
    <hi>Croatian LibreOffice Language Meta-Package</hi>
    <hr>Croatian LibreOffice Language Meta-Package</hr>
