@@ -28,9 +28,10 @@ English_SA_LO_main
    <fa>English_southafrican Language Meta-Package for LibreOffice</fa>
    <fil_PH>English_southafrican Language Meta-Package for LibreOffice</fil_PH>
    <fi>Englantilais_Etelä-Afrikkalainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet de langue anglaise (Afrique du Sud) pour LibreOffice</fr_BE>
+   <fr_BE>English_southafrican Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue anglaise (Afrique du Sud) pour LibreOffice</fr>
    <gl_ES>Meta-paquete de Idioma para LibreOffice para o inglés surafricano</gl_ES>
+   <gu>English_southafrican Language Meta-Package for LibreOffice</gu>
    <he_IL>English_southafrican Language Meta-Package for LibreOffice</he_IL>
    <hi>English_southafrican Language Meta-Package for LibreOffice</hi>
    <hr>English_southafrican Language Meta-Package for LibreOffice</hr>
