@@ -28,9 +28,10 @@ Esperanto_LO_Latest_full
    <fa>Esperanto Language Meta-Package for LibreOffice</fa>
    <fil_PH>Esperanto Language Meta-Package for LibreOffice</fil_PH>
    <fi>Esperanto-kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet de langue espérantiste pour LibreOffice</fr_BE>
+   <fr_BE>Esperanto Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet de langue espérantiste pour LibreOffice</fr>
    <gl_ES>Esperanto Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Esperanto Language Meta-Package for LibreOffice</gu>
    <he_IL>Esperanto Language Meta-Package for LibreOffice</he_IL>
    <hi>Esperanto Language Meta-Package for LibreOffice</hi>
    <hr>Esperanto Language Meta-Package for LibreOffice</hr>
@@ -50,7 +51,7 @@ Esperanto_LO_Latest_full
    <nl>Esperano Taal Meta-Pakket voor LibreOffice</nl>
    <pl>Meta-pakiet języka esperanto dla LibreOffice</pl>
    <pt_BR>Esperanto Pacote de Idioma para o LibreOffice</pt_BR>
-   <pt>Esperanto Language Meta-Package for LibreOffice</pt>
+   <pt>Meta-Pacote de linguagem em Esperanto para LibreOffice</pt>
    <ro>Esperanto Language Meta-Package for LibreOffice</ro>
    <ru>Esperanto Language Meta-Package for LibreOffice</ru>
    <sk>Esperanto Language Meta-Package for LibreOffice</sk>
