@@ -28,9 +28,10 @@ Finnish_LO_full
    <fa>Finnish Language Meta-Package for LibreOffice</fa>
    <fil_PH>Finnish Language Meta-Package for LibreOffice</fil_PH>
    <fi>Suomenkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet de langue finnoise pour LibreOffice</fr_BE>
+   <fr_BE>Finnish Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet de langue finnoise pour LibreOffice</fr>
    <gl_ES>Finés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Finnish Language Meta-Package for LibreOffice</gu>
    <he_IL>Finnish Language Meta-Package for LibreOffice</he_IL>
    <hi>Finnish Language Meta-Package for LibreOffice</hi>
    <hr>Finnish Language Meta-Package for LibreOffice</hr>
