@@ -28,9 +28,10 @@ Georgian_LO_Latest_main
    <fa>Georgian Language Meta-Package for LibreOffice</fa>
    <fil_PH>Georgian Language Meta-Package for LibreOffice</fil_PH>
    <fi>Georgialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet de langue géorgienne pour LibreOffice</fr_BE>
+   <fr_BE>Georgian Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet de langue géorgienne pour LibreOffice</fr>
    <gl_ES>Xeorxiano Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Georgian Language Meta-Package for LibreOffice</gu>
    <he_IL>Georgian Language Meta-Package for LibreOffice</he_IL>
    <hi>Georgian Language Meta-Package for LibreOffice</hi>
    <hr>Georgian Language Meta-Package for LibreOffice</hr>
