@@ -31,6 +31,7 @@ Guarani_LO_main
    <fr_BE>Guarani Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue guarani pour LibreOffice</fr>
    <gl_ES>Guaraní Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Guarani Language Meta-Package for LibreOffice</gu>
    <he_IL>Guarani Language Meta-Package for LibreOffice</he_IL>
    <hi>Guarani Language Meta-Package for LibreOffice</hi>
    <hr>Guarani Language Meta-Package for LibreOffice</hr>
@@ -59,7 +60,7 @@ Guarani_LO_main
    <sr>Guarani Language Meta-Package for LibreOffice</sr>
    <sv>Guarani Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Guarani สำหรับ LibreOffice</th>
-   <tr>LibreOffice için Paraguay Dili Üst-Paketi</tr>
+   <tr>LibreOffice için Guarani Dili Üst-Paketi</tr>
    <uk>Guarani Language Meta-Package for LibreOffice</uk>
    <vi>Guarani Language Meta-Package for LibreOffice</vi>
    <zh_CN>LibreOffice 瓜拉尼语语言包</zh_CN>
