@@ -28,9 +28,10 @@ Hebrew_LO_main
    <fa>Hebrew Language Meta-Package for LibreOffice</fa>
    <fil_PH>Hebrew Language Meta-Package for LibreOffice</fil_PH>
    <fi>Hepreankielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet en langue hébraïque pour LibreOffice</fr_BE>
+   <fr_BE>Hebrew Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue hébraïque pour LibreOffice</fr>
    <gl_ES>Hebreo Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Hebrew Language Meta-Package for LibreOffice</gu>
    <he_IL>Hebrew Language Meta-Package for LibreOffice</he_IL>
    <hi>Hebrew Language Meta-Package for LibreOffice</hi>
    <hr>Hebrew Language Meta-Package for LibreOffice</hr>
