@@ -21,23 +21,24 @@ Irish_Thunderbird
    <de>Irische Lokalisation von Thunderbird</de>
    <el>Ιρλανδικά για Firefox ESR</el>
    <en>Irish localisation of Thunderbird</en>
-   <es_ES>Irish localisation of Thunderbird</es_ES>
+   <es_ES>Localización Irlandés de Thunderbird</es_ES>
    <es>Localización Irlandés de Thunderbird</es>
    <et>Irish localisation of Thunderbird</et>
    <eu>Irish localisation of Thunderbird</eu>
    <fa>Irish localisation of Thunderbird</fa>
    <fil_PH>Irish localisation of Thunderbird</fil_PH>
    <fi>Irish localisation of Thunderbird</fi>
-   <fr_BE>Localisation en irlandais de Thunderbird</fr_BE>
+   <fr_BE>Irish localisation of Thunderbird</fr_BE>
    <fr>Localisation en irlandais de Thunderbird</fr>
    <gl_ES>Irish localisation of Thunderbird</gl_ES>
+   <gu>Irish localisation of Thunderbird</gu>
    <he_IL>Irish localisation of Thunderbird</he_IL>
    <hi>Irish localisation of Thunderbird</hi>
    <hr>Irish localisation of Thunderbird</hr>
    <hu>Irish localisation of Thunderbird</hu>
    <id>Irish localisation of Thunderbird</id>
    <is>Irish localisation of Thunderbird</is>
-   <it>Irish localisation of Thunderbird</it>
+   <it>Localizzazione irlandese di Thunderbird</it>
    <ja>アイルランド語版 Thunderbird</ja>
    <kk>Irish localisation of Thunderbird</kk>
    <ko>Irish localisation of Thunderbird</ko>
@@ -59,7 +60,7 @@ Irish_Thunderbird
    <sr>Irish localisation of Thunderbird</sr>
    <sv>Irländsk lokalisering av Thunderbird</sv>
    <th>Irish localisation of Thunderbird</th>
-   <tr>Irish localisation of Thunderbird</tr>
+   <tr>Thunderbird'ün İrlandaca yerelleştirmesi</tr>
    <uk>Irish localisation of Thunderbird</uk>
    <vi>Irish localisation of Thunderbird</vi>
    <zh_CN>Irish localisation of Thunderbird</zh_CN>
