@@ -28,9 +28,10 @@ Italian_LO_Latest_main
    <fa>Italian LibreOffice Language Meta-Package</fa>
    <fil_PH>Italian LibreOffice Language Meta-Package</fil_PH>
    <fi>Italialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet langue italienne pour LibreOffice</fr_BE>
+   <fr_BE>Italian LibreOffice Language Meta-Package</fr_BE>
    <fr>Méta-paquet langue italienne pour LibreOffice</fr>
    <gl_ES>Italiano Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Italian LibreOffice Language Meta-Package</gu>
    <he_IL>Italian LibreOffice Language Meta-Package</he_IL>
    <hi>Italian LibreOffice Language Meta-Package</hi>
    <hr>Italian LibreOffice Language Meta-Package</hr>
