@@ -31,8 +31,9 @@ Japanese_Firefox
    <fr_BE>Japanese localisation of Firefox</fr_BE>
    <fr>Localisation en japonais pour Firefox</fr>
    <gl_ES>Localización de Firefox ao xaponés</gl_ES>
+   <gu>Japanese localisation of Firefox</gu>
    <he_IL>תרגומי Firefox ליפנית</he_IL>
-   <hi>Japanese localisation of Firefox</hi>
+   <hi>फायरफॉक्स का जापानी संस्करण</hi>
    <hr>Japanese localisation of Firefox</hr>
    <hu>Japanese localisation of Firefox</hu>
    <id>Japanese localisation of Firefox</id>
