@@ -28,9 +28,10 @@ Kurmanji_LO_Latest_main
    <fa>Kurmanji Language Meta-Package for LibreOffice</fa>
    <fil_PH>Kurmanji Language Meta-Package for LibreOffice</fil_PH>
    <fi>Kurmandzinkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet en langue kurmanji pour LibreOffice</fr_BE>
+   <fr_BE>Kurmanji Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue kurmanji pour LibreOffice</fr>
    <gl_ES>Curmanji Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Kurmanji Language Meta-Package for LibreOffice</gu>
    <he_IL>Kurmanji Language Meta-Package for LibreOffice</he_IL>
    <hi>Kurmanji Language Meta-Package for LibreOffice</hi>
    <hr>Kurmanji Language Meta-Package for LibreOffice</hr>
