@@ -21,23 +21,24 @@ Latvian_Default_Firefox_esr
    <de>Lettische Lokalisation von “Firefox ESR”</de>
    <el>Λετονικά για Firefox ESR</el>
    <en>Latvian localisation of Firefox ESR</en>
-   <es_ES>Latvian localisation of Firefox ESR</es_ES>
+   <es_ES>Localización Letona de Firefox ESR</es_ES>
    <es>Localización Letón de Firefox ESR</es>
    <et>Latvian localisation of Firefox ESR</et>
    <eu>Latvian localisation of Firefox ESR</eu>
    <fa>Latvian localisation of Firefox ESR</fa>
    <fil_PH>Latvian localisation of Firefox ESR</fil_PH>
    <fi>Latvian localisation of Firefox ESR</fi>
-   <fr_BE>Localisation en letton de Firefox ESR</fr_BE>
+   <fr_BE>Latvian localisation of Firefox ESR</fr_BE>
    <fr>Localisation en letton de Firefox ESR</fr>
    <gl_ES>Latvian localisation of Firefox ESR</gl_ES>
+   <gu>Latvian localisation of Firefox ESR</gu>
    <he_IL>Latvian localisation of Firefox ESR</he_IL>
    <hi>Latvian localisation of Firefox ESR</hi>
    <hr>Latvian localisation of Firefox ESR</hr>
    <hu>Latvian localisation of Firefox ESR</hu>
    <id>Latvian localisation of Firefox ESR</id>
    <is>Latvian localisation of Firefox ESR</is>
-   <it>Latvian localisation of Firefox ESR</it>
+   <it>Localizzazione lettone di Firefox ESR</it>
    <ja>ラトビア語版 Firefox ESR</ja>
    <kk>Latvian localisation of Firefox ESR</kk>
    <ko>Latvian localisation of Firefox ESR</ko>
@@ -59,7 +60,7 @@ Latvian_Default_Firefox_esr
    <sr>Latvian localisation of Firefox ESR</sr>
    <sv>Lettländsk lokalisering av Firefox ESR</sv>
    <th>Latvian localisation of Firefox ESR</th>
-   <tr>Latvian localisation of Firefox ESR</tr>
+   <tr>Firefox ESR Letonca yerelleştirmesi</tr>
    <uk>Latvian localisation of Firefox ESR</uk>
    <vi>Latvian localisation of Firefox ESR</vi>
    <zh_CN>Latvian localisation of Firefox ESR</zh_CN>
