@@ -28,9 +28,10 @@ Ndebele_LO_main
    <fa>Ndebele Language Meta-Package for LibreOffice</fa>
    <fil_PH>Ndebele Language Meta-Package for LibreOffice</fil_PH>
    <fi>Ndebelekielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet en langue Ndebele pour LibreOffice</fr_BE>
+   <fr_BE>Ndebele Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue Ndebele pour LibreOffice</fr>
    <gl_ES>Ndebele Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Ndebele Language Meta-Package for LibreOffice</gu>
    <he_IL>Ndebele Language Meta-Package for LibreOffice</he_IL>
    <hi>Ndebele Language Meta-Package for LibreOffice</hi>
    <hr>Ndebele Language Meta-Package for LibreOffice</hr>
