@@ -18,7 +18,7 @@ Occitan_LO_full
    <ca>Metapaquet d'idioma Occità per LibreOffice</ca>
    <cs>Occitan Language Meta-Package for LibreOffice</cs>
    <da>Occitan Language Meta-Package for LibreOffice</da>
-   <de>Occitanisches Meta-Paket für LibreOffice</de>
+   <de>Okzitanisches Meta-Paket für LibreOffice</de>
    <el>LibreOffice στα Occitan</el>
    <en>Occitan Language Meta-Package for LibreOffice</en>
    <es_ES>Meta-Paquete de idioma Occitano para LibreOffice</es_ES>
@@ -28,9 +28,10 @@ Occitan_LO_full
    <fa>Occitan Language Meta-Package for LibreOffice</fa>
    <fil_PH>Occitan Language Meta-Package for LibreOffice</fil_PH>
    <fi>Oksitaaninen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet langue occitane pour LibreOffice</fr_BE>
+   <fr_BE>Occitan Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet langue occitane pour LibreOffice</fr>
    <gl_ES>Occitano Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Occitan Language Meta-Package for LibreOffice</gu>
    <he_IL>Occitan Language Meta-Package for LibreOffice</he_IL>
    <hi>Occitan Language Meta-Package for LibreOffice</hi>
    <hr>Occitan Language Meta-Package for LibreOffice</hr>
