@@ -31,8 +31,9 @@ Russian_Thunderbird
    <fr_BE>Russian localisation of Thunderbird</fr_BE>
    <fr>Localisation en russe pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird ao ruso</gl_ES>
+   <gu>Russian localisation of Thunderbird</gu>
    <he_IL>תרגומי Thunderbird לרוסית</he_IL>
-   <hi>Russian localisation of Thunderbird</hi>
+   <hi>थंडरबर्ड का रूसी संस्करण</hi>
    <hr>Russian localisation of Thunderbird</hr>
    <hu>Russian localisation of Thunderbird</hu>
    <id>Russian localisation of Thunderbird</id>
