@@ -28,9 +28,10 @@ Sinhala_LO_Latest_full
    <fa>Sinhala Language Meta-Package for LibreOffice</fa>
    <fil_PH>Sinhala Language Meta-Package for LibreOffice</fil_PH>
    <fi>Sinhalinkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-Paquet en langue cingalaise pour LibreOffice</fr_BE>
+   <fr_BE>Sinhala Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue cingalaise pour LibreOffice</fr>
    <gl_ES>Cingalés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Sinhala Language Meta-Package for LibreOffice</gu>
    <he_IL>Sinhala Language Meta-Package for LibreOffice</he_IL>
    <hi>Sinhala Language Meta-Package for LibreOffice</hi>
    <hr>Sinhala Language Meta-Package for LibreOffice</hr>
