@@ -28,9 +28,10 @@ Slovak_LO_main
    <fa>Slovak Language Meta-Package for LibreOffice</fa>
    <fil_PH>Slovak Language Meta-Package for LibreOffice</fil_PH>
    <fi>Slovakialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet langue slovaque pour LibreOffice</fr_BE>
+   <fr_BE>Slovak Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet langue slovaque pour LibreOffice</fr>
    <gl_ES>Eslovaco Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Slovak Language Meta-Package for LibreOffice</gu>
    <he_IL>Slovak Language Meta-Package for LibreOffice</he_IL>
    <hi>Slovak Language Meta-Package for LibreOffice</hi>
    <hr>Slovak Language Meta-Package for LibreOffice</hr>
