@@ -27,12 +27,13 @@ Slovak_Thunderbird
    <eu>Slovak localisation of Thunderbird</eu>
    <fa>Slovak localisation of Thunderbird</fa>
    <fil_PH>Slovak localisation of Thunderbird</fil_PH>
-   <fi>Slovakialainen Thunderbird-kotoistus</fi>
-   <fr_BE>Localisation en slovaque pour Thunderbird</fr_BE>
+   <fi>Slovakialainen kielipaketti Thunderbirdille</fi>
+   <fr_BE>Slovak localisation of Thunderbird</fr_BE>
    <fr>Localisation en slovaque pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird ao eslovaco</gl_ES>
+   <gu>Slovak localisation of Thunderbird</gu>
    <he_IL>Slovak localisation of Thunderbird</he_IL>
-   <hi>Slovak localisation of Thunderbird</hi>
+   <hi>थंडरबर्ड का स्लोवाक संस्करण</hi>
    <hr>Slovak localisation of Thunderbird</hr>
    <hu>Slovak localisation of Thunderbird</hu>
    <id>Slovak localisation of Thunderbird</id>
