@@ -31,8 +31,9 @@ Swedish_Thunderbird
    <fr_BE>Swedish localisation of Thunderbird</fr_BE>
    <fr>Localisation en suédois pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird ao sueco</gl_ES>
+   <gu>Swedish localisation of Thunderbird</gu>
    <he_IL>תרגומי Thunderbird לשוודית</he_IL>
-   <hi>Swedish localisation of Thunderbird</hi>
+   <hi>थंडरबर्ड का स्वीडिश संस्करण</hi>
    <hr>Swedish localisation of Thunderbird</hr>
    <hu>Swedish localisation of Thunderbird</hu>
    <id>Swedish localisation of Thunderbird</id>
