@@ -31,8 +31,9 @@ Ukrainian_Fonts
    <fr_BE>Ukrainian fonts packages</fr_BE>
    <fr>Paquets pour polices ukrainiennes</fr>
    <gl_ES>Paquetes de fontes ucraniano</gl_ES>
+   <gu>Ukrainian fonts packages</gu>
    <he_IL>Ukrainian fonts packages</he_IL>
-   <hi>Ukrainian fonts packages</hi>
+   <hi>यूक्रेनी मुद्रलिपि पैकेज</hi>
    <hr>Ukrainian fonts packages</hr>
    <hu>Ukrainian fonts packages</hu>
    <id>Ukrainian fonts packages</id>
