@@ -28,11 +28,12 @@ Ukrainian_LO_main
    <fa>Ukrainian localisation of LibreOffice</fa>
    <fil_PH>Ukrainian localisation of LibreOffice</fil_PH>
    <fi>Ukrainalainen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Localisation en ukrainien pour LibreOffice</fr_BE>
+   <fr_BE>Ukrainian localisation of LibreOffice</fr_BE>
    <fr>Localisation en ukrainien pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao ucraniano</gl_ES>
+   <gu>Ukrainian localisation of LibreOffice</gu>
    <he_IL>תרגומי LibreOffice לאוקראינית</he_IL>
-   <hi>Ukrainian localisation of LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस का यूक्रेनी संस्करण</hi>
    <hr>Ukrainian localisation of LibreOffice</hr>
    <hu>Ukrainian localisation of LibreOffice</hu>
    <id>Ukrainian localisation of LibreOffice</id>
