@@ -28,11 +28,12 @@ Uzbek_LO_Latest_main
    <fa>Uzbek Language Meta-Package for LibreOffice</fa>
    <fil_PH>Uzbek Language Meta-Package for LibreOffice</fil_PH>
    <fi>Uzbekinkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Méta-paquet langue ouzbèque pour LibreOffice</fr_BE>
+   <fr_BE>Uzbek Language Meta-Package for LibreOffice</fr_BE>
    <fr>Méta-paquet langue ouzbèque pour LibreOffice</fr>
    <gl_ES>Uzbeco Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Uzbek Language Meta-Package for LibreOffice</gu>
    <he_IL>Uzbek Language Meta-Package for LibreOffice</he_IL>
-   <hi>Uzbek Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु उज़्बेक भाषा मेटा-पैकेज</hi>
    <hr>Uzbek Language Meta-Package for LibreOffice</hr>
    <hu>Uzbek Language Meta-Package for LibreOffice</hu>
    <id>Uzbek Language Meta-Package for LibreOffice</id>
