@@ -28,9 +28,10 @@ Xhosa_LO_main
    <fa>Xhosa Language Meta-Package for LibreOffice</fa>
    <fil_PH>Xhosa Language Meta-Package for LibreOffice</fil_PH>
    <fi>Xhosankielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Meta-Paquet de langue Xhosa pour LibreOffice</fr_BE>
+   <fr_BE>Xhosa Language Meta-Package for LibreOffice</fr_BE>
    <fr>Meta-Paquet de langue Xhosa pour LibreOffice</fr>
    <gl_ES>Xosa Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Xhosa Language Meta-Package for LibreOffice</gu>
    <he_IL>Xhosa Language Meta-Package for LibreOffice</he_IL>
    <hi>Xhosa Language Meta-Package for LibreOffice</hi>
    <hr>Xhosa Language Meta-Package for LibreOffice</hr>
