@@ -21,16 +21,17 @@ KDE5
    <de>Vollständige Installation der Desktop-Umgebung KDE 5</de>
    <el>Πλήρης εγκατάσταση KDE5</el>
    <en>KDE5-full</en>
-   <es_ES>KDE5-full</es_ES>
+   <es_ES>KDE5-completo</es_ES>
    <es>KDE5-completo</es>
    <et>KDE5-full</et>
    <eu>KDE5-full</eu>
    <fa>KDE5-full</fa>
    <fil_PH>KDE5-full</fil_PH>
-   <fi>KDE5-full</fi>
-   <fr_BE>KDE5 complet</fr_BE>
+   <fi>KDE5-kokonainen</fi>
+   <fr_BE>KDE5-full</fr_BE>
    <fr>KDE5 complet</fr>
    <gl_ES>KDE5-full</gl_ES>
+   <gu>KDE5-full</gu>
    <he_IL>KDE5-full</he_IL>
    <hi>KDE5-full</hi>
    <hr>KDE5-full</hr>
@@ -54,12 +55,12 @@ KDE5
    <ro>KDE5-full</ro>
    <ru>KDE5-full</ru>
    <sk>KDE5-full</sk>
-   <sl>KDE5-full</sl>
+   <sl>KDE5-celota</sl>
    <sq>KDE5-full</sq>
    <sr>KDE5-full</sr>
    <sv>KDE5-full</sv>
    <th>KDE5-full</th>
-   <tr>KDE5-full</tr>
+   <tr>KDE5-tam</tr>
    <uk>KDE5-full</uk>
    <vi>KDE5-full</vi>
    <zh_CN>KDE5-full</zh_CN>
