@@ -21,23 +21,24 @@ Papirus antiX
    <de>Piktogramme (Ugs.: “Icons”) für antiX im Stil “Numix Bevil” (Vollständiger Satz)</de>
    <el>Πλήρης έκδοση εικονιδίων Papirus για antiX Linux</el>
    <en>Full version of Papirus icons for antiX Linux</en>
-   <es_ES>Full version of Papirus icons for antiX Linux</es_ES>
+   <es_ES>Versión completa de los iconos Papirus para antiX Linux</es_ES>
    <es>Versión completa de los iconos Papirus para antiX Linux</es>
    <et>Full version of Papirus icons for antiX Linux</et>
    <eu>Full version of Papirus icons for antiX Linux</eu>
    <fa>Full version of Papirus icons for antiX Linux</fa>
    <fil_PH>Full version of Papirus icons for antiX Linux</fil_PH>
    <fi>Full version of Papirus icons for antiX Linux</fi>
-   <fr_BE>Icônes pour antiX dans le style “Papirus” (version complète)</fr_BE>
+   <fr_BE>Full version of Papirus icons for antiX Linux</fr_BE>
    <fr>Icônes pour antiX dans le style “Papirus” (version complète)</fr>
    <gl_ES>Full version of Papirus icons for antiX Linux</gl_ES>
+   <gu>Full version of Papirus icons for antiX Linux</gu>
    <he_IL>Full version of Papirus icons for antiX Linux</he_IL>
    <hi>Full version of Papirus icons for antiX Linux</hi>
    <hr>Full version of Papirus icons for antiX Linux</hr>
    <hu>Full version of Papirus icons for antiX Linux</hu>
    <id>Full version of Papirus icons for antiX Linux</id>
    <is>Full version of Papirus icons for antiX Linux</is>
-   <it>Full version of Papirus icons for antiX Linux</it>
+   <it>Versione completa di icone Papirus per antiX Linux</it>
    <ja>AntiX Linux用 Papirusアイコンのフルバージョン</ja>
    <kk>Full version of Papirus icons for antiX Linux</kk>
    <ko>Full version of Papirus icons for antiX Linux</ko>
@@ -50,7 +51,7 @@ Papirus antiX
    <nl>Full version of Papirus icons for antiX Linux</nl>
    <pl>Full version of Papirus icons for antiX Linux</pl>
    <pt_BR>Conjunto completo de ícones Papirus para o antiX Linux</pt_BR>
-   <pt>Full version of Papirus icons for antiX Linux</pt>
+   <pt>Versão completa dos ícones Papirus para o antiX Linux</pt>
    <ro>Full version of Papirus icons for antiX Linux</ro>
    <ru>Full version of Papirus icons for antiX Linux</ru>
    <sk>Full version of Papirus icons for antiX Linux</sk>
