@@ -28,9 +28,10 @@ Scribus
    <fa>a desktop page layout program</fa>
    <fil_PH>a desktop page layout program</fil_PH>
    <fi>työpöytäsivuohjelma ulkoasulle</fi>
-   <fr_BE>Programme de mise en page</fr_BE>
+   <fr_BE>a desktop page layout program</fr_BE>
    <fr>Programme de mise en page</fr>
    <gl_ES>programa de paxinación electrónica (composición das publicación)</gl_ES>
+   <gu>a desktop page layout program</gu>
    <he_IL>a desktop page layout program</he_IL>
    <hi>a desktop page layout program</hi>
    <hr>a desktop page layout program</hr>
