@@ -21,23 +21,24 @@ Streamtuner2
    <de>Browser für Verzeichnisse von Radiosendern</de>
    <el>Πρόγραμμα περιήγησης για καταλόγους ραδιοφωνικών σταθμών</el>
    <en>Browser for radio station directories</en>
-   <es_ES>Browser for radio station directories</es_ES>
+   <es_ES>Navegador de directorios de emisoras de radio</es_ES>
    <es>Navegador de directorios de emisoras de radio</es>
    <et>Browser for radio station directories</et>
    <eu>Browser for radio station directories</eu>
    <fa>Browser for radio station directories</fa>
    <fil_PH>Browser for radio station directories</fil_PH>
    <fi>Browser for radio station directories</fi>
-   <fr_BE>Navigateur pour les répertoires de stations de radio</fr_BE>
+   <fr_BE>Browser for radio station directories</fr_BE>
    <fr>Navigateur pour les répertoires de stations de radio</fr>
    <gl_ES>Browser for radio station directories</gl_ES>
+   <gu>Browser for radio station directories</gu>
    <he_IL>Browser for radio station directories</he_IL>
    <hi>Browser for radio station directories</hi>
    <hr>Browser for radio station directories</hr>
    <hu>Browser for radio station directories</hu>
    <id>Browser for radio station directories</id>
    <is>Browser for radio station directories</is>
-   <it>Browser for radio station directories</it>
+   <it>Browser per elenchi di stazioni radio</it>
    <ja>ラジオ局のディレクトリ用ブラウザー</ja>
    <kk>Browser for radio station directories</kk>
    <ko>Browser for radio station directories</ko>
@@ -50,7 +51,7 @@ Streamtuner2
    <nl>Browser for radio station directories</nl>
    <pl>Browser for radio station directories</pl>
    <pt_BR>Navegador para diretórios de estações de rádio</pt_BR>
-   <pt>Browser for radio station directories</pt>
+   <pt>Pesquisar diretorias de estações de rádio</pt>
    <ro>Browser for radio station directories</ro>
    <ru>Browser for radio station directories</ru>
    <sk>Browser for radio station directories</sk>
