@@ -28,9 +28,10 @@ SuperTuxKart
    <fa>Mario kart style racing</fa>
    <fil_PH>Mario kart style racing</fil_PH>
    <fi>Mario Kartin tyylinen kilpa-ajopeli</fi>
-   <fr_BE>Jeu de courses de type Mario-kart</fr_BE>
+   <fr_BE>Mario kart style racing</fr_BE>
    <fr>Jeu de courses de type Mario-kart</fr>
    <gl_ES>Xogo de vídeo de carreiras de karts, do tipo Marío kart</gl_ES>
+   <gu>Mario kart style racing</gu>
    <he_IL>Mario kart style racing</he_IL>
    <hi>Mario kart style racing</hi>
    <hr>Mario kart style racing</hr>
