@@ -27,10 +27,11 @@ x11vnc
    <eu>VNC server for X window environments</eu>
    <fa>VNC server for X window environments</fa>
    <fil_PH>VNC server for X window environments</fil_PH>
-   <fi>VNC palvelin X-ikkunointi ympäristöihin</fi>
-   <fr_BE>Serveur VNC pour environnements X window</fr_BE>
+   <fi>VNC-palvelin X-ikkunointiympäristöihin</fi>
+   <fr_BE>VNC server for X window environments</fr_BE>
    <fr>Serveur VNC pour environnements X window</fr>
    <gl_ES>Servidor VNC para ambientes de lapelas "X"</gl_ES>
+   <gu>VNC server for X window environments</gu>
    <he_IL>VNC server for X window environments</he_IL>
    <hi>VNC server for X window environments</hi>
    <hr>VNC server for X window environments</hr>
