@@ -21,23 +21,24 @@ Xfce4
    <de>Installation der Desktop-Umgebung “Xfce 4” sowie des Displaymanagers “LightDM” zur grafischen Anmeldung.</de>
    <el>Εγκαταστήστε xfce4 και lightdm</el>
    <en>Install xfce4 and lightdm</en>
-   <es_ES>Install xfce4 and lightdm</es_ES>
+   <es_ES>Instalar xfce4 y lightdm</es_ES>
    <es>Instalar xfce4 y lightdm</es>
    <et>Install xfce4 and lightdm</et>
    <eu>Install xfce4 and lightdm</eu>
    <fa>Install xfce4 and lightdm</fa>
    <fil_PH>Install xfce4 and lightdm</fil_PH>
-   <fi>Install xfce4 and lightdm</fi>
+   <fi>Asenna xfce4 sekä lightdm</fi>
    <fr_BE>Install xfce4 and lightdm</fr_BE>
    <fr>Installer xfce4 et lightdm</fr>
    <gl_ES>Install xfce4 and lightdm</gl_ES>
+   <gu>Install xfce4 and lightdm</gu>
    <he_IL>Install xfce4 and lightdm</he_IL>
    <hi>Install xfce4 and lightdm</hi>
    <hr>Install xfce4 and lightdm</hr>
    <hu>Install xfce4 and lightdm</hu>
    <id>Install xfce4 and lightdm</id>
    <is>Install xfce4 and lightdm</is>
-   <it>Install xfce4 and lightdm</it>
+   <it>Installa xfce4 e lightdm</it>
    <ja>xfce 4 と lightdm をインストール</ja>
    <kk>Install xfce4 and lightdm</kk>
    <ko>Install xfce4 and lightdm</ko>
@@ -50,7 +51,7 @@ Xfce4
    <nl>Install xfce4 and lightdm</nl>
    <pl>Install xfce4 and lightdm</pl>
    <pt_BR>Instalação do xfce4 e do lightdm</pt_BR>
-   <pt>Install xfce4 and lightdm</pt>
+   <pt>Instalar xfce4 e lightdm</pt>
    <ro>Install xfce4 and lightdm</ro>
    <ru>Install xfce4 and lightdm</ru>
    <sk>Install xfce4 and lightdm</sk>
